FliKISS
=======

A `KISS <http://en.wikipedia.org/wiki/KISS_principle>`_ wiki engine inspired by `BlazeKISS <http://projet.idleman.fr/blazekiss/>`_ a fork of `Wikiss <http://wikiss.tuxfamily.org/>`_.

FliKISS does not require any database. Pages are stored in flat files using the `Markdown <http://daringfireball.net/projects/markdown/>`_ syntax.

Features
--------

- Namespaces
- Render WikiLinks
- Render tables
- Code syntax hilighting

Techonologies used
------------------

- `Python <http://www.python.org/>`_
- `Flask <http://flask.pocoo.org/>`_
- `Flask-WTF <https://flask-wtf.readthedocs.org/en/latest>`_ extension
- `Lepture's Markdown editor <https://github.com/lepture/editor>`_
- `Python Markdown <http://pythonhosted.org/Markdown/>`_
- `CherryPy <http://cherrypy.org/>`_ wsgi server
- `Lockfile <http://pythonhosted.org/lockfile/>`_
- `Pygments <http://pygments.org/>`_
- `Skeleton <http://getskeleton.com>`_ CSS framework
